You are viewing a plain text version of this content. The canonical link for it is here.
Posted to notifications@ant.apache.org by bo...@apache.org on 2012/03/21 05:59:26 UTC

svn commit: r1303281 - /ant/antlibs/compress/trunk/src/main/org/apache/ant/compress/resources/TarFileSet.java

Author: bodewig
Date: Wed Mar 21 04:59:26 2012
New Revision: 1303281

URL: http://svn.apache.org/viewvc?rev=1303281&view=rev
Log:
copy-paste error

Modified:
    ant/antlibs/compress/trunk/src/main/org/apache/ant/compress/resources/TarFileSet.java

Modified: ant/antlibs/compress/trunk/src/main/org/apache/ant/compress/resources/TarFileSet.java
URL: http://svn.apache.org/viewvc/ant/antlibs/compress/trunk/src/main/org/apache/ant/compress/resources/TarFileSet.java?rev=1303281&r1=1303280&r2=1303281&view=diff
==============================================================================
--- ant/antlibs/compress/trunk/src/main/org/apache/ant/compress/resources/TarFileSet.java (original)
+++ ant/antlibs/compress/trunk/src/main/org/apache/ant/compress/resources/TarFileSet.java Wed Mar 21 04:59:26 2012
@@ -77,7 +77,7 @@ public class TarFileSet extends ArchiveF
     }
 
     /**
      * Set the encoding used for this ZipFileSet.
      * @param enc encoding as String.
      * @since Compress Antlib 1.2
      */
@@ -87,15 +87,15 @@ public class TarFileSet extends ArchiveF
     }
 
     /**
      * Get the encoding used for this ZipFileSet.
      * @return String encoding.
      * @since Compress Antlib 1.2
      */
     public String getEncoding() {
         if (isReference()) {
             AbstractFileSet ref = getRef(getProject());
-            if (ref instanceof ZipFileSet) {
-                return ((ZipFileSet) ref).getEncoding();
+            if (ref instanceof TarFileSet) {
+                return ((TarFileSet) ref).getEncoding();
             } else {
                 return null;
             }
@@ -77,7 +77,7 @@ public class TarFileSet extends ArchiveF
 
     /**
-     * Set the encoding used for this ZipFileSet.
+     * Set the encoding used for this TarFileSet.
      * @param enc encoding as String.
      * @since Compress Antlib 1.2
@@ -87,15 +87,15 @@ public class TarFileSet extends ArchiveF
 
     /**
-     * Get the encoding used for this ZipFileSet.
+     * Get the encoding used for this TarFileSet.
      * @return String encoding.
      * @since Compress Antlib 1.2